@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\SqlParser;
 
-use PhpMyAdmin\SqlParser\Components\FunctionCall;
 use PhpMyAdmin\SqlParser\Components\OptionsArray;
 use Stringable;
 
@@ -62,6 +61,14 @@ abstract class Statement implements Stringable
      */
     public static $CLAUSES = [];
 
+    /**
+     * Options that can be given to GROUP BY component.
+     *
+     * @var array<string, int|array<int, int|string>>
+     * @psalm-var array<string, (positive-int|array{positive-int, ('var'|'var='|'expr'|'expr=')})>
+     */
+    public static $GROUP_OPTIONS = [];
+
     /**
      * @var array<string, int|array<int, int|string>>
      * @psalm-var array<string, (positive-int|array{positive-int, ('var'|'var='|'expr'|'expr=')})>
@@ -364,7 +371,11 @@ abstract class Statement implements Stringable
                     $parsedOptions = true;
                 }
             } elseif ($class === null) {
-                if (
+                if ($this instanceof Statements\SelectStatement && $token->value === 'WITH ROLLUP') {
+                    // Handle group options in Select statement
+                    // See Statements\SelectStatement::$GROUP_OPTIONS
+                    $this->group_options = OptionsArray::parse($parser, $list, static::$GROUP_OPTIONS);
+                } elseif (
                     $this instanceof Statements\SelectStatement
                     && ($token->value === 'FOR UPDATE'
                         || $token->value === 'LOCK IN SHARE MODE')
@@ -403,13 +414,6 @@ abstract class Statement implements Stringable
             }
 
             $this->after($parser, $list, $token);
-
-            // #223 Here may make a patch, if last is delimiter, back one
-            if ($class !== FunctionCall::class || $list->offsetGet($list->idx)->type !== Token::TYPE_DELIMITER) {
-                continue;
-            }
-
-            --$list->idx;
         }
 
         // This may be corrected by the parser.
