@@ -9,29 +9,30 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class LimitTest extends TestCase
 {
-    public function testBuildWithoutOffset()
+    public function testBuildWithoutOffset(): void
     {
         $component = new Limit(1);
         $this->assertEquals(Limit::build($component), '0, 1');
     }
 
-    public function testBuildWithOffset()
+    public function testBuildWithOffset(): void
     {
         $component = new Limit(1, 2);
         $this->assertEquals(Limit::build($component), '2, 1');
     }
 
     /**
-     * @param mixed $test
-     *
      * @dataProvider parseProvider
      */
-    public function testParse($test)
+    public function testParse(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function parseProvider()
+    /**
+     * @return string[][]
+     */
+    public function parseProvider(): array
     {
         return [
             ['parser/parseLimitErr1'],
