@@ -10,7 +10,7 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class ParameterDefinitionTest extends TestCase
 {
-    public function testParse()
+    public function testParse(): void
     {
         $component = ParameterDefinition::parse(
             new Parser(),
@@ -20,7 +20,7 @@ class ParameterDefinitionTest extends TestCase
         $this->assertEquals('b', $component[1]->name);
     }
 
-    public function testParseComplex()
+    public function testParseComplex(): void
     {
         $parser = new Parser();
         $component = ParameterDefinition::parse(
