@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class ParameterTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider parameterProvider
      */
-    public function testParameter($test)
+    public function testParameter(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function parameterProvider()
+    /**
+     * @return string[][]
+     */
+    public function parameterProvider(): array
     {
         return [
             ['misc/parseParameter'],
