@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class RenameStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider renameProvider
      */
-    public function testRename($test)
+    public function testRename(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function renameProvider()
+    /**
+     * @return string[][]
+     */
+    public function renameProvider(): array
     {
         return [
             ['parser/parseRename'],
